(define-module (glicid packages openldap)
 #:use-module (guix build-system gnu)
 #:use-module (guix download)
 #:use-module (guix packages)
 #:use-module (guix utils)
 #:use-module ((gnu packages openldap) #:prefix gnu:)
 #:use-module (gnu packages autotools)
 #:use-module (gnu packages compression)
 #:use-module (gnu packages databases)
 #:use-module (gnu packages libevent)
 #:use-module (gnu packages password-utils)
 #:use-module (gnu packages pkg-config)
 #:use-module (gnu packages tls)
)

(define-public openldap
  (package
    (inherit gnu:openldap)
    (name "openldap")
    (version "2.6.0")
    (source (origin
      (method url-fetch)
      (uri (list
        (string-append "https://www.openldap.org/software/download/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://gpl.savoirfairelinux.net/pub/mirrors/openldap/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://repository.linagora.org/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.ntua.gr/mirror/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror-hk.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.dti.ad.jp/pub/net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.lyrahosting.com/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
      ))
      (sha256 ( base32 "0kqswk8pxgnlibh0kz6py3a2x3yh9pfk6pyr2nx9lgjpmh75h75p" ))
      )
    )
    (build-system gnu-build-system)
    (inputs `(
      ("libltdl", libltdl)
      ("pkg-config", pkg-config)
      ("libevent", libevent)
      ("openssl", openssl)
      ("argon2", argon2)
      ("wiredtiger", wiredtiger)
      ("snappy", snappy)
      ("lz4", lz4)
      ,@(package-inputs gnu:openldap)
    ))
    (arguments '(
      ; this is needed because the make check does not work inside guix
      #:tests? #f
      #:configure-flags '(
        "--enable-debug"
        "--enable-dynamic"
        "--enable-syslog"
        "--enable-ipv6"
        "--enable-local"
        "--enable-slapd"
        "--enable-dynacl"
        "--enable-aci"
        "--enable-cleartext"
        "--enable-crypt"
        "--enable-spasswd"
        "--enable-modules"
        "--enable-rlookups"
        "--enable-slapi"
        "--enable-backends=mod"
        "--enable-overlays=mod"
        "--enable-argon2"
        "--enable-balancer"
        "--disable-static"
        "--enable-shared"
        "--with-tls=openssl"
      )
      #:make-flags '("STRIP=")
      #:phases (modify-phases %standard-phases
        (add-before 'build 'make-depend
          (lambda* (#:key input #:allow-other-keys)
            (invoke "make" "depend")
          )
        )
      )
    ))
  )
)

(define-public openldap-2.5.7
  (package
    (inherit openldap)
    (name "openldap")
    (version "2.5.7")
    (source (origin
      (method url-fetch)
      (uri (list
        (string-append "https://www.openldap.org/software/download/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://gpl.savoirfairelinux.net/pub/mirrors/openldap/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://repository.linagora.org/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.ntua.gr/mirror/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror-hk.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.dti.ad.jp/pub/net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.lyrahosting.com/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
      ))
      (sha256 ( base32 "1ayr76sa5hjwldqzis5v71sbp88hd3hysc00gw1raqn33c05g5za" ))
      )
    )
  )
)

(define-public openldap-2.5.9
  (package
    (inherit openldap)
    (name "openldap")
    (version "2.5.9")
    (source (origin
      (method url-fetch)
      (uri (list
        (string-append "https://www.openldap.org/software/download/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://gpl.savoirfairelinux.net/pub/mirrors/openldap/" "openldap-release/openldap-" version ".tgz")
        (string-append "http://repository.linagora.org/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.ntua.gr/mirror/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror-hk.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "ftp://ftp.dti.ad.jp/pub/net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.koddos.net/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
        (string-append "https://mirror.lyrahosting.com/OpenLDAP/" "openldap-release/openldap-" version ".tgz")
      ))
      (sha256 ( base32 "17pvwrj27jybbmjqpv0p7kd2qa4i6jnp134lz7cxa0sqrbs153n0" ))
      )
    )
  )
)


(define-public nss-pam-ldapd
  (package
    (inherit nss-pam-ldapd)
  )
)
